bayespy.inference.vmp.nodes.constant.Constant
=============================================

.. currentmodule:: bayespy.inference.vmp.nodes.constant

.. autoclass:: Constant

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Constant.__init__
      ~Constant.add_plate_axis
      ~Constant.broadcasting_multiplier
      ~Constant.delete
      ~Constant.get_mask
      ~Constant.get_moments
      ~Constant.get_shape
      ~Constant.has_plotter
      ~Constant.lower_bound_contribution
      ~Constant.move_plates
      ~Constant.plot
      ~Constant.set_plotter
      ~Constant.set_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Constant.plates
      ~Constant.plates_multiplier
   
   